@@ -47,7 +47,7 @@ class CallNotify(hildondesktop.StatusMenuItem):
 		
 		# add GUI buttons
 		self.addGUI()
-		dbg('constructor end')
+		self.dbg('constructor end')
 	
     def addGUI(self):
 	  # add GUI buttons                                              
